@@ -72,7 +72,7 @@ def build_opts_str(mnt):
             otheropts = v
         elif k in _OPTS:
             opts.append(k + ':' + unicode(v))
-    opts.extend(o)
+    opts.extend(otheropts)
     return ', '.join(sorted(opts))
 
 def get_setting_from_opts(ns, options):
@@ -178,9 +178,8 @@ def mount_create(ns, device, mountpoint, fs_type=None, options=None):
                                                       FileSystemSpec=device)
     msg = '%s on %s' % (device, mountpoint)
     if ret != 0:
-        errname = service.SyncCreateMount.CreateMountValues.value_name(ret)
-        raise LmiFailed('Cannot create mount: %s: %s.' % (
-                msg, errname))
+        raise LmiFailed('Cannot create mount: %s: %s' % (
+                msg, _err))
 
     LOG().info('Successfully created mount: %s', msg)
 
